const path = require('path');
const webpack = require('webpack');
const WebpackHelper = require("@studyportals/webpack-helper");
const DllManifestGenerator = require("@studyportals/bob-manifest-generator").DllManifestGenerator;

module.exports = (env, details) => {

	const configuration = WebpackHelper.create({
		entry: {
			tooltip_v2: [
				"@studyportals/tooltip/dist/tooltip.js",
				"@studyportals/tooltip/dist/tooltip.css"
			]
		},
		output: {
			fileName: `[name]${details.mode === 'production' ? '.min': ''}`,
			hash: false
		},
		preset: "typescript",
		common: {
			output: {
				library: "[name]"
			},
			plugins: [
				new webpack.DllPlugin({
					path: path.resolve(__dirname, `./dist/tooltip${details.mode === 'production' ? '.min' : ''}.json`),
					name: "[name]",
					entryOnly: true
				})
			],
			resolve: {
				extensions: ['*', '.ts', '.js', '.json']
			},
			module: {
				rules: [
					{
						test: /\.js|css$/,
						enforce: "pre",
						use: ["source-map-loader"]
					}
				]
			}
		},
		production: {
			plugins: [
				new DllManifestGenerator()
			],
			optimization: {
				moduleIds: 'named'
			}
		}
	});

	return configuration.get(details.mode);
};
