import { Tooltip } from "./tooltip";
import { Position } from "../enums/position";

export class ContextualTooltip extends Tooltip {

	constructor(options) {
		super(options);
	}
	
	public createTooltipElement(): void {

		this.tooltip.classList.add('Tooltip');
		if(this.position === Position.BOTTOM) { this.tooltip.classList.add('Bottom'); }
		this.tooltip.style.display = "none";
		this.tooltip.innerHTML = `
			<div class="TooltipInner">
				${typeof this.content === 'string' ? this.content : this.content.outerHTML}
			</div>
			<div class="TooltipArrow"></div>
		`;
	}

	public addEventListeners(): void {

		if(this.element === null) { return; }

		this.element.addEventListener('mouseenter', () => {
			this.closeAllTooltips();
			window.requestAnimationFrame(() => this.open());
		});

		this.element.addEventListener('mouseleave', () => {

			this.close();
		});

		document.addEventListener('Tooltip/CloseAllTooltips', () => {

			this.close();
		});
	}

	private closeAllTooltips(): void {

		document.dispatchEvent(
			new Event('Tooltip/CloseAllTooltips')
		);
	}
}