import { Tooltip } from "./tooltip";
import { TooltipState } from "../enums/state";
import { Position } from "../enums/position";

export class GuidanceTooltip extends Tooltip {

	constructor(options) {
		super(options);
	}

	public createTooltipElement(): void {

		this.tooltip.classList.add('Tooltip');
		this.tooltip.classList.add('Guidance');
		if(this.position === Position.BOTTOM) { this.tooltip.classList.add('Bottom'); }

		this.tooltip.style.display = "none";
		this.tooltip.innerHTML = `
			<div class="TooltipInner">
				${typeof this.content === 'string' ? this.content : this.content.outerHTML}
				<button class="TooltipClose">
					<i class="TooltipCloseIcon lnr-cross"></i>
				</button>
			</div>
			<div class="TooltipArrow"></div>
		`;
	}

	public addEventListeners(): void {

		if(this.element === null) { return; }

		const closeButton: HTMLElement | null = this.element.querySelector('.TooltipClose');
		const embeddedLinks: NodeList = this.element.querySelectorAll('a');

		if(!this.disableClick) {

			this.element.addEventListener('click', () => {
				this.state === TooltipState.CLOSED ? this.open() : this.close();
			});
		}

		if(closeButton !== null) { 

			this.element.querySelector('.TooltipClose')!.addEventListener('click', (e: Event) => {
				e.stopPropagation();
				this.close();
				// Fire onClose callback when there is one
				if(this.onClose) { this.onClose(); }
			});
		}

		if(embeddedLinks.length > 0) {

			Array.from(embeddedLinks).forEach((link: Node) => {

				link.addEventListener('click', (e: Event) => {
					e.stopPropagation();
					this.close();
				});
			});
		}
	}
}