import { ContextualTooltip } from "../../../../../src/domain/contextual-tooltip";
import { Position } from "../../../../../src/enums/position";

let testInstance;
let testElement = document.createElement('div');

describe('contextual-tooltip.ts', () => {

	beforeEach(() => {

		testInstance = new ContextualTooltip({
			element: testElement,
			content: "Test"
		});
	});

	it('createTooltipElement(): Creates the tooltip with a string as content and positioned on top.', () => {

		//given
		testInstance.tooltip = {
			classList: {
				remove: jest.fn(),
				add: jest.fn()
			},
			style: {
				display: ''
			},
			innerHTML: ''
		};

		//when
		testInstance.createTooltipElement();

		//then
		expect(testInstance.tooltip.innerHTML).toEqual(`
			<div class="TooltipInner">
				Test
			</div>
			<div class="TooltipArrow"></div>
		`);
		expect(testInstance.tooltip.style.display).toEqual('none');
	});

	it('createTooltipElement(): Creates the tooltip with an element as content and positioned on the bottom.', () => {

		//given
		testInstance.tooltip = {
			classList: {
				remove: jest.fn(),
				add: jest.fn()
			},
			style: {
				display: ''
			},
			innerHTML: ''
		};
		testInstance.position = Position.BOTTOM;
		testInstance.content = document.createElement('div');

		//when
		testInstance.createTooltipElement();

		//then
		expect(testInstance.tooltip.innerHTML).toEqual(`
			<div class="TooltipInner">
				<div></div>
			</div>
			<div class="TooltipArrow"></div>
		`);
		expect(testInstance.tooltip.style.display).toEqual('none');
		expect(testInstance.tooltip.classList.add).toHaveBeenCalledWith('Bottom');
	});

	it('addEventListeners(): Returns when element is null.', () => {

		//given
		testInstance.element = null;
		const spy = jest.spyOn(testInstance, "addEventListeners");

		//when
		testInstance.addEventListeners();

		//then
		expect(spy).toHaveReturned();
	});

	it('addEventListeners(): Adds all eventListeners.', () => {

		//given
		testInstance.element = {
			addEventListener: jest.fn()
		};
		const spy = jest.spyOn(document, 'addEventListener');

		//when
		testInstance.addEventListeners();

		//then
		expect(testInstance.element.addEventListener).toHaveBeenCalledTimes(2);
		expect(spy).toHaveBeenCalledTimes(1);
	});

	it('addEventListeners(): Adds all eventListeners.', () => {

		//given
		let eventFired: boolean = false;
		document.addEventListener('Tooltip/CloseAllTooltips', () => eventFired = true);

		//when
		testInstance.closeAllTooltips();

		//then
		expect(eventFired).toBeTruthy();
	});
});