import { GuidanceTooltip } from "../../../../../src/domain/guidance-tooltip";
import { Position } from "../../../../../src/enums/position";

let testInstance;
let testElement = document.createElement('div');

describe('guidance-tooltip.ts', () => {

	beforeEach(() => {

		testInstance = new GuidanceTooltip({
			element: testElement,
			content: "Test"
		});
	});

	it('createTooltipElement(): Creates the tooltip with a string as content and positioned on top.', () => {

		//given
		testInstance.tooltip = {
			classList: {
				remove: jest.fn(),
				add: jest.fn()
			},
			style: {
				display: ''
			},
			innerHTML: ''
		};

		//when
		testInstance.createTooltipElement();

		//then
		expect(testInstance.tooltip.innerHTML).toEqual(`
			<div class="TooltipInner">
				Test
				<button class="TooltipClose">
					<i class="TooltipCloseIcon lnr-cross"></i>
				</button>
			</div>
			<div class="TooltipArrow"></div>
		`);
		expect(testInstance.tooltip.style.display).toEqual('none');
	});

	it('createTooltipElement(): Creates the tooltip with an element as content and positioned on the bottom.', () => {

		//given
		testInstance.tooltip = {
			classList: {
				remove: jest.fn(),
				add: jest.fn()
			},
			style: {
				display: ''
			},
			innerHTML: ''
		};
		testInstance.position = Position.BOTTOM;
		testInstance.content = document.createElement('div');

		//when
		testInstance.createTooltipElement();

		//then
		expect(testInstance.tooltip.innerHTML).toEqual(`
			<div class="TooltipInner">
				<div></div>
				<button class="TooltipClose">
					<i class="TooltipCloseIcon lnr-cross"></i>
				</button>
			</div>
			<div class="TooltipArrow"></div>
		`);
		expect(testInstance.tooltip.style.display).toEqual('none');
		expect(testInstance.tooltip.classList.add).toHaveBeenCalledWith('Bottom');
	});

	it('addEventListeners(): Returns when element is null.', () => {

		//given
		testInstance.element = null;
		const spy = jest.spyOn(testInstance, "addEventListeners");

		//when
		testInstance.addEventListeners();

		//then
		expect(spy).toHaveReturned();
	});

	it('addEventListeners(): Adds listeners when conditions are met.', () => {

		//given
		const link = document.createElement('a');
		const closeButton = document.createElement('button');
		testInstance.element = {
			querySelector() {
				return closeButton
			},
			querySelectorAll() {
				return [
					link
				]
			},
			addEventListener: jest.fn()
		};
		testInstance.disableClick = false;
		testInstance.content = document.createElement('div');
		const spyLink = jest.spyOn(link, "addEventListener");
		const spyCloseButton = jest.spyOn(closeButton, "addEventListener");

		//when
		testInstance.addEventListeners();

		//then
		expect(testInstance.element.addEventListener).toHaveBeenCalledTimes(1);
		expect(spyLink).toHaveBeenCalledTimes(1);
		expect(spyCloseButton).toHaveBeenCalledTimes(1);
	});

	it('addEventListeners(): Doesn\'t add any listeners when no conditions are met.', () => {

		//given
		testInstance.element = {
			querySelector() {
				return null
			},
			querySelectorAll() {
				return []
			},
			addEventListener: jest.fn()
		};
		testInstance.disableClick = true;

		//when
		testInstance.addEventListeners();

		//then
		expect(testInstance.element.addEventListener).toHaveBeenCalledTimes(0);
	});
});