const path = require('path');
const WebpackHelper = require("@studyportals/webpack-helper");
const HtmlWebpackPlugin = require("html-webpack-plugin");
const MiniCssExtractPlugin = require('mini-css-extract-plugin');

const configuration = WebpackHelper.create({
	entry: {
		tooltip_v2: './src/index.ts'
	},
	output: {
		path: path.resolve(__dirname, "./dist"),
        publicPath: "/dist/",
		hash: false,
	},
	preset: "typescript",
	common: {
		output: {
			libraryTarget: "umd"
		},
		plugins: [
			new HtmlWebpackPlugin({
				hash: true,
				title: "Tooltip",
				template: path.resolve(__dirname, './src/index.html'),
				filename: path.resolve(__dirname, './index.html')
			}),
			new MiniCssExtractPlugin({
				filename: 'tooltip.css'
			})
		]
	},
	development: {
		devServer: {
			client: {
				overlay: true
			},
			devMiddleware: {
				writeToDisk: true
			},
			open: true,
			static: path.join(__dirname, '.')
		}
	},
	production: {
		output: {
			filename: 'tooltip.js'
		},
	}
});

module.exports = (env, details) => configuration.get(details.mode);
